@@ -10,8 +10,12 @@ use Text::vCard::Node;
 # See this module for your basic parser functions
 use base qw(Text::vFile::asData);
 use vars qw ($VERSION %lookup %node_aliases @simple);
-$VERSION = '1.4';
+$VERSION = '1.5';
 
+# If the node's data does not break down use this
+my @default_field = qw(value);
+
+# If it does use these
 %lookup = (
 	'ADR' => ['po_box','extended','street','city','region','post_code','country'],
 	'N' => ['family','given','middle','prefixes','suffixes'],
@@ -33,10 +37,10 @@ $VERSION = '1.4';
 # Now we want lowercase as well
 map { push(@simple,lc($_)) } @simple;
 
-&_import;
+&import;
 
 # Generate the methods
-sub _import {
+sub import {
 	no strict 'refs';
 	no warnings;
 	for my $node (@simple) { 
@@ -64,8 +68,6 @@ sub _import {
 	}
 }
 
-my @default_field = qw(value);
-
 =head1 NAME
 
 Text::vCard - a package to edit and create a single vCard (RFC 2426) 
@@ -423,6 +425,11 @@ sub _add_node {
 	return $last_node;
 }
 
+=head2 import()
+
+  This is called to create methods at run time. If you want to 
+load T:vC at runtime using 'require T:vC' would also have to call 
+'import' by hand.
 
 =head1 AUTHOR
 
